@@ -7,12 +7,12 @@ from .forms import *
 
 class LemmaAdmin(admin.ModelAdmin):
     model = Lemma
-    list_display = ('Label','getSpellings')
+    list_display = ('label','get_spellings')
 
 admin.site.register(Lemma, LemmaAdmin)
 
 class WordFormAdmin(admin.ModelAdmin):
     model = WordForm
-    list_display = ('Lemma','getSpellings','getTranscriptions')
+    list_display = ('lemma','get_spellings','get_transcriptions')
 
 admin.site.register(WordForm, WordFormAdmin)
