@@ -13,7 +13,7 @@ from django.core.files import File
 from .models import *
 from .forms import *
 from .helper import fetch_celex_resource
-from .tasks import doReset,doStringSelect
+from .tasks import doReset,doStringSelect,doNGramAnalysis
 
 #old
 #call_command('reset','stimuli', interactive=False,verbosity=0)
@@ -75,6 +75,16 @@ def string_selection(request):
     form = StringForm()
     return render(request,'celex/form.html',{'form':form})
 
+@login_required
+def analyze_ngrams(request):
+    if request.method == 'POST':
+        form = ResetForm(request.POST)
+        if form.is_valid():
+            doNGramAnalysis.delay()
+            return redirect(index)
+    form = ResetForm()
+    return render(request,'celex/form.html',{'form':form})
+
 
 #def getFreqBreaks(qs):
     #freqs = sorted(qs.values_list('Frequency',flat=True))
